from hf_hub_ctranslate2 import TranslatorCT2fromHfHub, GeneratorCT2fromHfHub, MultiLingualTranslatorCT2fromHfHub
from hf_hub_ctranslate2._private.utils import download_model
from transformers import AutoTokenizer


def test_translator(model_name="michaelfeil/ct2fast-flan-alpaca-base"):
    model = TranslatorCT2fromHfHub(
        model_name_or_path=model_name, device="cpu", compute_type="int8"
    )

    outputs = model.generate(
        ["How do you call a fast Flan-ingo?", "Translate to german: How are you doing?"]
    )
    assert len(outputs) == 2
    assert len(outputs[0]) != len(outputs[1])
    assert "flan" in outputs[0].lower()
    for o in outputs:
        assert isinstance(o, str)

def test_multilingualtranslator(model_name="michaelfeil/ct2fast-m2m100_418M"):
    model = MultiLingualTranslatorCT2fromHfHub(
        model_name_or_path=model_name, device="cpu", compute_type="int8",
        tokenizer=AutoTokenizer.from_pretrained(f"facebook/{model_name.split('-')[-1]}")
    )

    outputs = model.generate(
        ["How do you call a fast Flamingo?", "Wie geht es dir?"],
        src_lang=["en", "de"],
        tgt_lang=["de", "fr"]
    )
    assert len(outputs) == 2
    assert len(outputs[0]) != len(outputs[1])
    assert "nennt" in outputs[0].lower()
    assert "comment" in outputs[1].lower()
    for o in outputs:
        assert isinstance(o, str)

def test_generator(model_name="michaelfeil/ct2fast-pythia-160m"):
    model = GeneratorCT2fromHfHub(
        model_name_or_path=model_name, device="cpu", compute_type="int8"
    )

    outputs = model.generate(
        ["How do you call a fast Flan-ingo?", "Translate to german: How are you doing?"]
    )
    assert len(outputs) == 2
    assert len(outputs[0]) != len(outputs[1])
    assert "flan" in outputs[0].lower()
    for o in outputs:
        assert isinstance(o, str)


def test_generator_single(model_name="michaelfeil/ct2fast-pythia-160m"):
    model_path = download_model(model_name)
    tokenizer = AutoTokenizer.from_pretrained(model_path)

    model = GeneratorCT2fromHfHub(
        model_name_or_path=model_path,
        device="cpu",
        compute_type="int8",
        tokenizer=tokenizer,
    )

    outputs = model.generate("How do you call a fast Flan-ingo?")
    assert isinstance(outputs, str)
    assert "flan" in outputs.lower()


if __name__ == "__main__":
    test_generator()
    test_translator()



from setuptools import find_packages, setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

version = " . "
with open("hf_hub_ctranslate2/__init__.py", "r", encoding="utf-8") as fh:
    lines = fh.readlines()
    for l in lines[::-1]:
        if "__version__" in l and "=" in l:
            print(l)
            version = l.split("__version__")[-1]
            version = version.replace("=", "").replace("'", "").replace('"', "").strip()
            break
if len(version.split(".")) != 3:
    raise ValueError(f"Version incorrect: {version}")


setup(
    name="hf_hub_ctranslate2",
    packages=find_packages(include="hf_hub_ctranslate2"),
    version=version,
    description=("Connecting Transfromers on HuggingfaceHub with Ctranslate2 "),
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Michael Feil",
    license="MIT",
    url="https://github.com/michaelfeil/hf-hub-ctranslate2",
    project_urls={
        "Bug Tracker": "https://github.com/michaelfeil/hf-hub-ctranslate2/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: POSIX :: Linux",
    ],
    install_requires=[
        "ctranslate2>=3.13.0",
        "transformers>=4.28.0",
        "huggingface-hub",
        "typing_extensions",
    ],
)
